************
Publications
************

#. | **The halo finding problem revisited: a deep revision of the ASOHF code**
   | David Valles-Perez, Susana Planelles, Vicent Quilis
   | `2205.02245 <https://arxiv.org/abs/2205.02245>`_

#. | **Learning cosmology and clustering with cosmic graphs**
   | Pablo Villanueva-Domingo, Francisco Villaescusa-Navarro
   | `2204.13713 <https://arxiv.org/abs/2204.13713>`_

#. | **Constraining cosmology with machine learning and galaxy clustering: the CAMELS-SAM suite**
   | Lucia A. Perez, Shy Genel, Francisco Villaescusa-Navarro, Rachel S. Somerville, Austen Gabrielpillai, Daniel Anglés-Alcázar, Benjamin D. Wandelt, L.Y. Aaron Yung
   | | `2204.02408 <https://arxiv.org/abs/2204.02408>`_ | `video <https://www.youtube.com/watch?v=sx0RCW2p4eU&t=178s>`__ | 

#. | **Breaking baryon-cosmology degeneracy with the electron density power spectrum**
   | Andrina Nicola, Francisco Villaescusa-Navarro, David N. Spergel, Jo Dunkley, Daniel Anglés-Alcázar, Romeel Davé, Shy Genel, Lars Hernquist, Daisuke Nagai, Rachel S. Somerville, Benjamin D. Wandelt
   | | `2201.04142 <https://arxiv.org/abs/2201.04142>`_ | `video <https://www.youtube.com/watch?v=D_CLangkIDE>`__ | 

#. | **The Circumgalactic Medium from the CAMELS Simulations: Forecasting Constraints on Feedback Processes from Future Sunyaev-Zeldovich Observations**
   | Emily Moser, Nicholas Battaglia, Daisuke Nagai, Erwin Lau, Luis Fernando Machado Poletti Valle, Francisco Villaescusa-Navarro, Stefania Amodeo, Daniel Angles-Alcazar, Greg L. Bryan, Romeel Dave, Lars Hernquist, Mark Vogelsberger
   | | `2201.02708 <https://arxiv.org/abs/2201.02708>`_ | `blog <https://www.camel-simulations.org/single-post/the-circumgalactic-medium-with-the-sunyaev-zeldovich-effect>`__ |

#. | **Cosmology with one galaxy?**
   | Francisco Villaescusa-Navarro, Jupiter Ding, Shy Genel, Stephanie Tonnesen, Valentina La Torre, David N. Spergel, Romain Teyssier, Yin Li, Caroline Heneka, Pablo Lemos, Daniel Anglés-Alcázar, Daisuke Nagai, Mark Vogelsberger
   | | `2201.02202 <https://arxiv.org/abs/2201.02202>`_ | `video <https://www.youtube.com/watch?v=4AfjqEj_MaI>`__ | `Quanta Magazine article <https://www.quantamagazine.org/with-one-galaxy-ai-defines-a-whole-simulated-universe-20220120/>`_ | `New Yorker article <https://www.newyorker.com/science/elements/what-can-we-learn-about-the-universe-from-just-one-galaxy>`_ | 

#. | **The CAMELS project: public data release**
   | Francisco Villaescusa-Navarro, Shy Genel, Daniel Anglés-Alcázar, Lucia A. Perez, Pablo Villanueva-Domingo, Digvijay Wadekar, Helen Shao, Faizan G. Mohammad, Sultan Hassan, Emily Moser, Erwin T. Lau, Luis Fernando Machado Poletti Valle, Andrina Nicola, Leander Thiele, Yongseok Jo, Oliver H. E. Philcox, Benjamin D. Oppenheimer, Megan Tillman, ChangHoon Hahn, Neerav Kaushal, Alice Pisani, Matthew Gebhardt, Ana Maria Delgado, Joyce Caliendo, Christina Kreisch, Kaze W.K. Wong, William R. Coulton, Michael Eickenberg, Gabriele Parimbelli, Yueying Ni, Ulrich P. Steinwandel, Valentina La Torre, Romeel Dave, Nicholas Battaglia, Daisuke Nagai, David N. Spergel, Lars Hernquist, Blakesley Burkhart, Desika Narayanan, Benjamin Wandelt, Rachel S. Somerville, Greg L. Bryan, Matteo Viel, Yin Li, Vid Irsic, Katarina Kraljic, Mark Vogelsberger
   | | `2201.01300 <https://arxiv.org/abs/2201.01300>`_ | `video <https://www.youtube.com/watch?v=6Vgc72a_VpY>`_ | `press release <https://www.simonsfoundation.org/2022/01/06/the-largest-suite-of-cosmic-simulations-for-ai-training-is-now-free-to-download-already-spurring-discoveries/>`__ | 

#. | **Augmenting astrophysical scaling relations with machine learning : application to reducing the SZ flux-mass scatter**
   | Digvijay Wadekar, Leander Thiele, Francisco Villaescusa-Navarro, J. Colin Hill, David N. Spergel, Miles Cranmer, Nicholas Battaglia, Daniel Anglés-Alcázar, Lars Hernquist, Shirley Ho
   | | `2201.01305 <https://arxiv.org/abs/2201.01305>`_ | `video <https://www.youtube.com/watch?v=w_ohkLYMSzs>`__ | 

#. | **Percent-level constraints on baryonic feedback with spectral distortion measurements**
   | Leander Thiele, Digvijay Wadekar, J. Colin Hill, Nicholas Battaglia, Jens Chluba, Francisco Villaescusa-Navarro, Lars Hernquist, Mark Vogelsberger, Daniel Anglés-Alcázar, Federico Marinacci
   | | `2201.01663 <https://arxiv.org/abs/2201.01663>`_ | `video <https://www.youtube.com/watch?v=u2tEG1nLwV8&t=2s>`__ | `blog <https://www.camel-simulations.org/single-post/what-can-we-learn-from-our-universe-s-climate>`__ | 

#. | **Weighing the Milky Way and Andromeda with Artificial Intelligence**
   | Pablo Villanueva-Domingo, Francisco Villaescusa-Navarro, Shy Genel, Daniel Anglés-Alcázar, Lars Hernquist, Federico Marinacci, David N. Spergel, Mark Vogelsberger, Desika Narayanan
   | | `2111.14874 <https://arxiv.org/abs/2111.14874>`_ | `video (26'-56') <https://www.youtube.com/watch?v=07k2JH6c0lE>`__ | 

#. | **Inferring halo masses with Graph Neural Networks**
   | Pablo Villanueva-Domingo, Francisco Villaescusa-Navarro, Daniel Anglés-Alcázar, Shy Genel, Federico Marinacci, David N. Spergel, Lars Hernquist, Mark Vogelsberger, Romeel Dave, Desika Narayanan
   | | `2111.08683 <https://arxiv.org/abs/2111.08683>`_ | `video (26'-51') <https://www.youtube.com/watch?v=07k2JH6c0lE>`__ | 

#. | **HIFlow: Generating Diverse HI Maps Conditioned on Cosmology using Normalizing Flow**
   | Sultan Hassan, Francisco Villaescusa-Navarro, Benjamin Wandelt, David N. Spergel, Daniel Anglés-Alcázar, Shy Genel, Miles Cranmer, Greg L. Bryan, Romeel Davé, Rachel S. Somerville, Michael Eickenberg, Desika Narayanan, Shirley Ho, Sambatra Andrianomena
   | | `2110.02983 <https://arxiv.org/abs/2110.02983>`_ | `video <https://www.youtube.com/watch?v=wDRd7MojD3I&t=1s>`__ | 

#. | **The CAMELS Multifield Dataset: Learning the Universe's Fundamental Parameters with Artificial Intelligence**
   | Francisco Villaescusa-Navarro, Shy Genel, Daniel Angles-Alcazar, Leander Thiele, Romeel Dave, Desika Narayanan, Andrina Nicola, Yin Li, Pablo Villanueva-Domingo, Benjamin Wandelt, David N. Spergel, Rachel S. Somerville, Jose Manuel Zorrilla Matilla, Faizan G. Mohammad, Sultan Hassan, Helen Shao, Digvijay Wadekar, Michael Eickenberg, Kaze W.K. Wong, Gabriella Contardo, Yongseok Jo, Emily Moser, Erwin T. Lau, Luis Fernando Machado Poletti Valle, Lucia A. Perez, Daisuke Nagai, Nicholas Battaglia, Mark Vogelsberger
   | | `2109.10915 <https://arxiv.org/abs/2109.10915>`_ | `website <https://camels-multifield-dataset.readthedocs.io>`_ | 

#. | **Robust marginalization of baryonic effects for cosmological inference at the field level**
   | Francisco Villaescusa-Navarro, Shy Genel, Daniel Angles-Alcazar, David N. Spergel, Yin Li, Benjamin Wandelt, Leander Thiele, Andrina Nicola, Jose Manuel Zorrilla Matilla, Helen Shao, Sultan Hassan, Desika Narayanan, Romeel Dave, Mark Vogelsberger
   | | `2109.10360 <https://arxiv.org/abs/2109.10360>`_ | `astrobites <https://astrobites.org/2021/11/06/camels-ai/>`__ | 
   
#. | **Multifield Cosmology with Artificial Intelligence**
   | Francisco Villaescusa-Navarro, Daniel Anglés-Alcázar, Shy Genel, David N. Spergel, Yin Li, Benjamin Wandelt, Andrina Nicola, Leander Thiele, Sultan Hassan, Jose Manuel Zorrilla Matilla, Desika Narayanan, Romeel Dave, Mark Vogelsberger
   | | `2109.09747 <https://arxiv.org/abs/2109.09747>`_ | `video (17'-38') <https://www.youtube.com/watch?v=NxR_kDlHhGM&t=1671s>`__ | 

#. | **Inpainting hydrodynamical maps with deep learning**
   | Faizan G. Mohammad, Francisco Villaescusa-Navarro, Shy Genel, Daniel Angles-Alcazar, Mark Vogelsberger
   | `2109.07070 <https://arxiv.org/abs/2109.07070>`_
   
#. | **Finding universal relations in subhalo properties with artificial intelligence**
   | Helen Shao, Francisco Villaescusa-Navarro, Shy Genel, David N. Spergel, Daniel Angles-Alcazar, Lars Hernquist, Romeel Dave, Desika Narayanan, Gabriella Contardo, Mark Vogelsberger
   | | `2109.04484 <https://arxiv.org/abs/2109.04484>`_ | `video <https://www.youtube.com/watch?v=_lIXL4-wkZ0&t=1724s>`__ | `blog <https://www.camel-simulations.org/single-post/dark-matter-halos-and-universal-relations>`__ | 

#. | **Neural networks as optimal estimators to marginalize over baryonic effects**
   | Francisco Villaescusa-Navarro, Benjamin D. Wandelt, Daniel Anglés-Alcázar, Shy Genel, Jose Manuel Zorrilla Mantilla, Shirley Ho, David N. Spergel
   | `2011.05992 <https://arxiv.org/abs/2011.05992>`_

#. | **The CAMELS project: Cosmology and Astrophysics with MachinE Learning Simulations**    
   | Francisco Villaescusa-Navarro, Daniel Anglés-Alcázar, Shy Genel, David N. Spergel, Rachel S. Somerville, Romeel Dave, Annalisa Pillepich, Lars Hernquist, Dylan Nelson, Paul Torrey, Desika Narayanan, Yin Li, Oliver Philcox, Valentina La Torre, Ana Maria Delgado, Shirley Ho, Sultan Hassan, Blakesley Burkhart, Digvijay Wadekar, Nicholas Battaglia, Gabriella Contardo
   | | `2010.00619 <https://arxiv.org/abs/2010.00619>`_ | `video (0'-13') <https://www.youtube.com/watch?v=NxR_kDlHhGM&t=1671s>`__ | `podcast (in Italian) <https://open.spotify.com/episode/36U5cKw7OAzc2HoIQeb4mq>`_ | `blog <https://www.camel-simulations.org/single-post/the-camels-project>`__ | `press release <https://www.simonsfoundation.org/2021/07/07/record-breaking-suite-of-cosmic-simulations-aims-to-identify-universes-parameters/>`__ | 
